@@ -75,7 +75,7 @@ define ([
                 entry,
                 selection;
         
-            if ($.isNumeric(sel) && sel >= 0 && sel <= len) {
+            if ($.isNumeric(sel) && sel > 0 && sel <= len) {
                 // we can only select the entry if we have sufficient priv level
                 selection = target.pull(dmo.entries[sel]);
                 if (coreLib.privCheck(selection.aclProfile)) {
@@ -225,10 +225,13 @@ define ([
             }
 
             // console.log("sel === " + sel + " and len === " + len);
-            if (sel >= 0 && sel <= len) {
+            if (sel > 0 && sel <= len) {
                 // console.log("sel " + sel + " is within range");
+                // the selection number the user sees is array index + 1, because
+                // otherwise the miniMenu selections would be numbered starting
+                // from zero, which is unintuitive for non-programmers
+                selection = target.pull(currentTarget.miniMenu.entries[sel - 1]);
                 // we can only select the item if we have sufficient priv level
-                selection = target.pull(currentTarget.miniMenu.entries[sel]);
                 if (coreLib.privCheck(selection.aclProfile)) {
                     //console.log('Selection ' + sel + ' passed priv check');
                     item = selection;
@@ -554,7 +557,7 @@ define ([
             var dfo = target.pull(dfn);
             return function (state, opts) {
                 currentTarget = dfo;
-                console.log('Entering start method of target ' + dfn);
+                console.log('Entering start method of target ' + dfn + ', unadulterated opts', opts);
                 var entry,
                     i,
                     populateArray = [];
@@ -563,8 +566,8 @@ define ([
                 }
                 opts.populate = ('populate' in opts) ? opts.populate : "true";
                 opts.resultLine = ('resultLine' in opts) ? opts.resultLine : "&nbsp";
-                opts.resultLine = (opts.resultLine === null) ? "&nbsp" : opts.resultLine;
                 opts.inputId = ('inputId' in opts) ? opts.inputId : null;
+                console.log("opts", opts);
                 // determine dform "state" (i.e. starting content of form entries)
                 if (! state) {
                     state = stack.getState();
@@ -585,10 +588,10 @@ define ([
                 }
                 // call first populate function to trigger sequential,
                 // asynchronous population of all entries with "populate" property
+                coreLib.displayResult(opts.resultLine);
                 if (opts.populate && populateArray.length > 0) {
                     populate.bootstrap(populateArray);
                 }
-                coreLib.displayResult(opts.resultLine);
                 // listen for user input in form
                 dformListen(dfn, state, opts.inputId);
             };
